"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildPattern = buildPattern;
exports.buildRegExp = buildRegExp;
var _encoder = require("./encoder/encoder");
var _elements = require("./utils/elements");
/**
 * Generate RegExp object from elements with optional flags.
 *
 * @param elements Single regex element or array of elements
 * @param flags RegExp flags object
 * @returns RegExp object
 */
function buildRegExp(sequence, flags) {
  const pattern = (0, _encoder.encodeSequence)((0, _elements.ensureArray)(sequence)).pattern;
  const flagsString = encodeFlags(flags ?? {});
  return new RegExp(pattern, flagsString);
}

/**
 * Generate regex pattern from elements.
 * @param elements Single regex element or array of elements
 * @returns regex pattern string
 */
function buildPattern(sequence) {
  return (0, _encoder.encodeSequence)((0, _elements.ensureArray)(sequence)).pattern;
}
function encodeFlags(flags) {
  let result = '';
  if (flags.global) result += 'g';
  if (flags.ignoreCase) result += 'i';
  if (flags.multiline) result += 'm';
  if (flags.hasIndices) result += 'd';
  return result;
}
//# sourceMappingURL=builders.js.map