"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.capture = capture;
exports.ref = ref;
var _encoder = require("../encoder/encoder");
var _elements = require("../utils/elements");
/**
 * Creates a capturing group which allows the matched pattern to be available:
 * - in the match results (`String.match`, `String.matchAll`, or `RegExp.exec`)
 * - in the regex itself, through {@link ref}
 */
function capture(sequence, options) {
  return {
    type: 'capture',
    children: (0, _elements.ensureArray)(sequence),
    options,
    encode: encodeCapture
  };
}

/**
 * Creates a reference, also known as backreference, which allows matching
 * again the exact text that a capturing group previously matched.
 *
 * In order to form a valid regex, the reference must use the same name as
 * a capturing group earlier in the expression.
 *
 * @param name - Name of the capturing group to reference.
 */
function ref(name) {
  return {
    type: 'reference',
    name,
    encode: encodeReference
  };
}
function encodeCapture() {
  var _this$options;
  const name = (_this$options = this.options) === null || _this$options === void 0 ? void 0 : _this$options.name;
  if (name) {
    return {
      precedence: 'atom',
      pattern: `(?<${name}>${(0, _encoder.encodeSequence)(this.children).pattern})`
    };
  }
  return {
    precedence: 'atom',
    pattern: `(${(0, _encoder.encodeSequence)(this.children).pattern})`
  };
}
function encodeReference() {
  return {
    precedence: 'atom',
    pattern: `\\k<${this.name}>`
  };
}
//# sourceMappingURL=capture.js.map