"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.lookahead = lookahead;
var _encoder = require("../encoder/encoder");
var _elements = require("../utils/elements");
/**
 * Positive lookahead assertion.
 *
 * A positive lookahead assertion is a zero-width assertion that matches a group of characters only if it is followed by a specific group of characters.
 *
 * @example
 * ```ts
 * lookahead("a");
 * // /(?=a)/
 *
 * lookahead(["a", "b", "c"]);
 * // /(?=abc)/
 * ```
 */

function lookahead(sequence) {
  return {
    type: 'lookahead',
    children: (0, _elements.ensureArray)(sequence),
    encode: encodeLookahead
  };
}
function encodeLookahead() {
  return {
    precedence: 'atom',
    pattern: `(?=${(0, _encoder.encodeSequence)(this.children).pattern})`
  };
}
//# sourceMappingURL=lookahead.js.map