"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.encodeAtom = encodeAtom;
exports.encodeSequence = encodeSequence;
var _text = require("../utils/text");
function encodeSequence(elements) {
  const encodedNodes = elements.map(n => encodeNode(n));
  return concatSequence(encodedNodes);
}
function encodeAtom(elements) {
  return wrapAtom(encodeSequence(elements));
}
function encodeNode(element) {
  if (typeof element === 'string') {
    return encodeText(element);
  }
  if (typeof element === 'object' && element instanceof RegExp) {
    return encodeRegExp(element);
  }
  if (typeof element.encode !== 'function') {
    throw new Error(`\`encodeNode\`: unknown element type ${element.type}`);
  }
  return element.encode();
}
function encodeText(text) {
  if (text.length === 0) {
    throw new Error('`encodeText`: received text should not be empty');
  }

  // Optimize for single character case
  if (text.length === 1) {
    return {
      precedence: 'atom',
      pattern: (0, _text.escapeText)(text)
    };
  }
  return {
    precedence: 'sequence',
    pattern: (0, _text.escapeText)(text)
  };
}
function encodeRegExp(regexp) {
  const pattern = regexp.source;

  // Encode at safe precedence
  return {
    precedence: isAtomicPattern(pattern) ? 'atom' : 'disjunction',
    pattern
  };
}

// This is intended to catch only some popular atomic patterns like char classes.
function isAtomicPattern(pattern) {
  var _pattern$match, _pattern$match2;
  if (pattern.length === 1) {
    return true;
  }
  if (pattern.startsWith('[') && pattern.endsWith(']') && ((_pattern$match = pattern.match(/[[\]]/g)) === null || _pattern$match === void 0 ? void 0 : _pattern$match.length) === 2) {
    return true;
  }
  if (pattern.startsWith('(') && pattern.endsWith(')') && ((_pattern$match2 = pattern.match(/[()]/g)) === null || _pattern$match2 === void 0 ? void 0 : _pattern$match2.length) === 2) {
    return true;
  }
  return false;
}
function concatSequence(encoded) {
  if (encoded.length === 1) {
    return encoded[0];
  }
  return {
    precedence: 'sequence',
    pattern: encoded.map(n => (n.precedence === 'disjunction' ? wrapAtom(n) : n).pattern).join('')
  };
}
function wrapAtom(encoded) {
  if (encoded.precedence === 'atom') {
    return encoded;
  }
  return {
    precedence: 'atom',
    pattern: `(?:${encoded.pattern})`
  };
}
//# sourceMappingURL=encoder.js.map