import { encodeSequence } from './encoder/encoder';
import { ensureArray } from './utils/elements';

/**
 * Generate RegExp object from elements with optional flags.
 *
 * @param elements Single regex element or array of elements
 * @param flags RegExp flags object
 * @returns RegExp object
 */
export function buildRegExp(sequence, flags) {
  const pattern = encodeSequence(ensureArray(sequence)).pattern;
  const flagsString = encodeFlags(flags ?? {});
  return new RegExp(pattern, flagsString);
}

/**
 * Generate regex pattern from elements.
 * @param elements Single regex element or array of elements
 * @returns regex pattern string
 */
export function buildPattern(sequence) {
  return encodeSequence(ensureArray(sequence)).pattern;
}
function encodeFlags(flags) {
  let result = '';
  if (flags.global) result += 'g';
  if (flags.ignoreCase) result += 'i';
  if (flags.multiline) result += 'm';
  if (flags.hasIndices) result += 'd';
  return result;
}
//# sourceMappingURL=builders.js.map