import { encodeSequence } from '../encoder/encoder';
import { ensureArray } from '../utils/elements';

/**
 * Positive lookbehind assertion.
 *
 * A positive lookbehind assertion is a zero-width assertion that matches a group of characters only if it is preceded by a specific group of characters.
 *
 * @example
 * ```ts
 * lookbehind("a");
 * // /(?<=a)/
 *
 * lookbehind(["a", "b", "c"]);
 * // /(?<=abc)/
 * ```
 */

export function lookbehind(sequence) {
  return {
    type: 'lookbehind',
    children: ensureArray(sequence),
    encode: encodeLookbehind
  };
}
function encodeLookbehind() {
  return {
    precedence: 'atom',
    pattern: `(?<=${encodeSequence(this.children).pattern})`
  };
}
//# sourceMappingURL=lookbehind.js.map