import { encodeSequence } from '../encoder/encoder';
import { ensureArray } from '../utils/elements';

/**
 * Negative lookahead assertion.
 *
 * A negative lookahead assertion is a zero-width assertion that matches a group of characters only if it is not followed by a specific group of characters.
 *
 * @example
 * ```ts
 * negativeLookahead("a");
 * // /(?=a)/
 *
 * negativeLookahead(["a", "b", "c"]);
 * // /(?=abc)/
 * ```
 */

export function negativeLookahead(sequence) {
  return {
    type: 'negativeLookahead',
    children: ensureArray(sequence),
    encode: encodeNegativeLookahead
  };
}
function encodeNegativeLookahead() {
  return {
    precedence: 'atom',
    pattern: `(?!${encodeSequence(this.children).pattern})`
  };
}
//# sourceMappingURL=negative-lookahead.js.map