import type { RegexConstruct, RegexElement, RegexSequence } from '../types';
/**
 * Positive lookahead assertion.
 *
 * A positive lookahead assertion is a zero-width assertion that matches a group of characters only if it is followed by a specific group of characters.
 *
 * @example
 * ```ts
 * lookahead("a");
 * // /(?=a)/
 *
 * lookahead(["a", "b", "c"]);
 * // /(?=abc)/
 * ```
 */
export interface Lookahead extends RegexConstruct {
    type: 'lookahead';
    children: RegexElement[];
}
export declare function lookahead(sequence: RegexSequence): Lookahead;
//# sourceMappingURL=lookahead.d.ts.map