import type { RegexConstruct, RegexElement, RegexSequence } from '../types';
/**
 * Negative lookahead assertion.
 *
 * A negative lookahead assertion is a zero-width assertion that matches a group of characters only if it is not followed by a specific group of characters.
 *
 * @example
 * ```ts
 * negativeLookahead("a");
 * // /(?=a)/
 *
 * negativeLookahead(["a", "b", "c"]);
 * // /(?=abc)/
 * ```
 */
export interface NegativeLookahead extends RegexConstruct {
    type: 'negativeLookahead';
    children: RegexElement[];
}
export declare function negativeLookahead(sequence: RegexSequence): NegativeLookahead;
//# sourceMappingURL=negative-lookahead.d.ts.map