import type { RegexConstruct, RegexElement, RegexSequence } from '../types';
/**
 * Negative lookbehind assertion.
 *
 * A negative lookbehind assertion is a zero-width assertion that matches a group of characters only if it is not preceded by a specific group of characters.
 *
 * @example
 * ```ts
 * negativeLookbehind("a");
 * // /(?<!a)/
 *
 * negativeLookbehind(["a", "b", "c"]);
 * // /(?<!abc)/
 * ```
 */
export interface NegativeLookbehind extends RegexConstruct {
    type: 'negativeLookbehind';
    children: RegexElement[];
}
export declare function negativeLookbehind(sequence: RegexSequence): NegativeLookbehind;
//# sourceMappingURL=negative-lookbehind.d.ts.map